@@ -141,12 +141,7 @@ int mMain_items_count = sizeof(mMain_items) / sizeof(GtkItemFactoryEntry);
 
 
 struct gpe_icon my_icons[] = {
-  { "save" },
-  { "cancel" },
-  { "delete" },
-  { "properties" },
   { "exit" },
-  { "refresh" },
   { "local-package", PREFIX "/share/pixmaps/local-package-16.png" },
   { "icon", PREFIX "/share/pixmaps/gpe-package.png" }
 };
@@ -961,7 +956,6 @@ create_fMain (void)
   toolbar = gtk_toolbar_new ();
   gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar),
 			       GTK_ORIENTATION_HORIZONTAL);
-  gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
 
   bApply = gtk_toolbar_insert_stock (GTK_TOOLBAR (toolbar), GTK_STOCK_APPLY,
 			   _("Apply package selection"), _("Apply package selection"),
